@@ -6,4 +6,5 @@ from django.apps import AppConfig
 class ResourceConfig(AppConfig):
     default_auto_field = 'django.db.models.BigAutoField'
     name = 'xj_resource'
-    verbose_name = u'资源系统'
+    verbose_name = u'Ⅵ 资源系统'
+    sort = 6
