@@ -3,22 +3,23 @@ import base64
 import hashlib
 import os
 from pathlib import Path
+import random
 import re
 import time
 
 from main.settings import BASE_DIR
 from ..models import ResourceImageGroup
 from ..utils.digit_algorithm import DigitAlgorithm
-from ..utils.x_config import XConfig
-from ..utils.x_dict import XDict
+from ..utils.j_config import JConfig
+from ..utils.j_dict import JDict
 
 module_dir = Path(__file__).parent.parent
-root_config = XDict(XConfig.get_section(str(BASE_DIR) + '/config.ini', 'xj_resource', encode='utf-8-sig'))
-module_config = XDict(XConfig.get_section(str(module_dir) + '/config.ini', 'xj_resource', encode='utf-8-sig'))
-
+root_config = JDict(JConfig.get_section(str(BASE_DIR) + '/config.ini', 'xj_resource', encode='utf-8-sig'))
+module_config = JDict(JConfig.get_section(str(module_dir) + '/config.ini', 'xj_resource', encode='utf-8-sig'))
 if not BASE_DIR:
     print("MSA ERROR: BASE_DIR is not find, check setting.py please!")
 
+
 class ResourceUploadService:
     """
     @class 资源上传服务。
@@ -40,14 +41,13 @@ class ResourceUploadService:
     origin_filename = None  # 原文件名
     save_dir = None  # 保存目录
     pseudo_dir = None  # 伪静态目录
-    __save_absolute_file_path = None  # 完整上传路径，包含文件名
 
     # 私有成员，仅限类内查看
     # 配置组
     __root_config = root_config  # 根配置，第一配置，
     __module_config = module_config  # 模块配置，第二配置
-    __upload_dir = None  # 上传文件的写入目录。真实目录，因为大部分情况下，并不希望用户看到文件存放的真实路径
-    __upload_url = None  # 上传文件的链接地址。虚拟目录，因为大部分情况下，并不希望用户看到文件存放的真实路径
+    __upload_dir = None  # 上传文件的写入目录。真实目录，相对项目路径，因为大部分情况下，并不希望用户看到文件存放的真实路径
+    __upload_url = None  # 上传文件的链接地址。虚拟目录，相对链接路径，因为大部分情况下，并不希望用户看到文件存放的真实路径
     __upload_host = None  # 上传文件的主机
     __upload_format = None  # 支持的文件格式列表
     __upload_limit = None  # 上传文件大小限制，单位：字节
@@ -57,6 +57,7 @@ class ResourceUploadService:
     __file_stream = None  # 上传文件流
 
     __save_absolute_dir = None  # 保存文件的绝对目录
+    __save_absolute_file_path = None  # 完整文件绝对路径，包含文件名
 
     # 构造函数，导入配置文件
     def __init__(self, upload_type='image'):
@@ -74,6 +75,7 @@ class ResourceUploadService:
             self.__upload_formats = c1.image_formats or c2.image_formats or None
             self.__upload_prefix = c1.image_prefix or c2.image_prefix or 'img_'
             self.__upload_limit = c1.image_limit or c2.image_limit or None
+            self.__upload_absolute_dir = c1.image_upload_absolute_dir or c2.image_upload_absolute_dir or None
 
         if upload_type.strip().lower() == 'file':
             self.__upload_dir = c1.file_upload_dir or c2.file_upload_dir or "/media/upload/files/"
@@ -82,6 +84,7 @@ class ResourceUploadService:
             self.__upload_formats = c1.file_formats or c2.file_formats or None
             self.__upload_prefix = c1.image_prefix or c2.image_prefix or 'file_'
             self.__upload_limit = c1.file_limit or c2.file_limit or None
+            self.__upload_absolute_dir = c1.file_upload_absolute_dir or c2.file_upload_absolute_dir or None
 
         if upload_type.strip().lower() == 'video':
             self.__upload_dir = c1.file_upload_dir or c2.file_upload_dir or "/media/upload/videos/"
@@ -90,6 +93,7 @@ class ResourceUploadService:
             self.__upload_formats = c1.file_formats or c2.file_formats or None
             self.__upload_prefix = c1.image_prefix or c2.image_prefix or 'video_'
             self.__upload_limit = c1.file_limit or c2.file_limit or None
+            self.__upload_absolute_dir = c1.video_upload_absolute_dir or c2.video_upload_absolute_dir or None
 
     # 初始化，基本信息、目录、文件等，初始化完成后可直接写入
     def init(self, input_file, by_month=False, user_id=None, title=None, group_id=None, limit_size=None):
@@ -149,10 +153,14 @@ class ResourceUploadService:
         if not save_dir:
             save_dir = self.__upload_dir
         if by_month:
-            save_dir = f"{save_dir}/{month}/".replace('//', '/')
-            pseudo_dir = f"{pseudo_dir}/{month}/".replace('//', '/')
+            # 注：添加对多余路径分隔符/\检查
+            save_dir = re.sub(r"[/\\]{1,2}", "/", f"/{save_dir}/{month}/")
+            pseudo_dir = re.sub(r"[/\\]{1,2}", "/", f"/{pseudo_dir}/{month}/")
 
-        save_absolute_dir = str(BASE_DIR) + save_dir
+        # 如果配置了绝对路径则使用绝对路径，否则使用相对项目路径
+        save_absolute_dir = re.sub(r"[/\\]{1,3}", "/", f"{str(BASE_DIR)}/{save_dir}")
+        if self.__upload_absolute_dir:
+            save_absolute_dir = self.__upload_absolute_dir = self.__upload_absolute_dir + month if by_month else ''
         # 不存在则创建目录
         if not os.path.exists(save_absolute_dir):
             os.makedirs(save_absolute_dir)
@@ -161,7 +169,7 @@ class ResourceUploadService:
             return None, "目录创建失败，请检查是否有目录权限：" + save_absolute_dir
 
         # print("> init_dir: save_dir:", save_dir)
-        print("> init_dir: save_absolute_dir:", save_absolute_dir)
+        # print("> init_dir: save_absolute_dir:", save_absolute_dir)
         self.save_dir = save_dir
         self.pseudo_dir = pseudo_dir
         self.__save_absolute_dir = save_absolute_dir
@@ -175,26 +183,33 @@ class ResourceUploadService:
         @return file_info, error_text {tuple} 文件目录，错误码
         @description 验证文件是否合法，同时生成文件配置信息
         """
-        # 一检查文件名
+        # 一检查文件名。
         self.origin_filename = self.__input_file.name
         ret = re.search(r'(.*)\.(\w{3,5})$', self.__input_file.name)
         if not ret:
             return None, '上传的文件名错误，格式后辍应为3-5个字符'
         self.origin_title = ret.group(1)
         self.suffix = ret.group(2)
-        self.filename = f"{self.__upload_prefix}{DigitAlgorithm.make_unicode_16()}.{self.suffix}"
-        self.__save_absolute_file_path = (str(BASE_DIR) + self.save_dir + self.filename).replace("//", "/")
-        # print("> init_file: save_absolute_dir:", self.save_absolute_dir)
-
-        # 二检查文件格式
-        if self.__upload_formats and self.__upload_formats.strip() != '*' and self.suffix \
-                and self.suffix not in self.__upload_formats.split(","):
-            return None, '上传文件格式错误，支持：' + self.__upload_formats
 
         # 三检查文件流
         self.__file_stream = self.__input_file.read()
         if not self.__file_stream:
             return None, '文件流读取失败'
+        self.md5 = self.get_md5()
+
+        # 生成唯一的文件名
+        self.filename = f"{self.__upload_prefix}{DigitAlgorithm.make_unicode_16(self.md5)}.{self.suffix}"
+        # 注：添加对多余路径分隔符/\检查
+        self.__save_absolute_file_path = re.sub(r"[/\\]{1,3}", "/", f"{str(BASE_DIR)}/{self.save_dir}/{self.filename}")
+        if self.__upload_absolute_dir:
+            self.__save_absolute_file_path = re.sub(r"[/\\]{1,3}", "/", f"{self.__upload_absolute_dir}/{self.filename}")
+        # print("> init_file: save_absolute_dir:", self.save_absolute_dir)
+
+        # 二检查文件格式。注：添加多余空格检查
+        # print("> init_file __upload_format_list:", self.__upload_formats.replace(' ', '').split(","))
+        if self.__upload_formats and self.__upload_formats.strip() != '*' and self.suffix \
+                and self.suffix not in self.__upload_formats.replace(' ', '').split(","):
+            return None, '上传文件格式错误，支持：' + self.__upload_formats
 
         # 四检查文件大小
         self.size = size = len(self.__file_stream)
@@ -217,7 +232,7 @@ class ResourceUploadService:
         self.__file_info['format'] = self.suffix
         self.__file_info['size'] = self.size
         self.__file_info['thumb'] = None
-        self.__file_info['md5'] = self.md5 = self.get_md5()
+        self.__file_info['md5'] = self.md5
         self.__file_info['snapshot'] = {
             'origin_filename': self.origin_filename,
             'upload_host': self.__upload_host,  # 当代码移植后，域名发生变化，可以通过上传主机查找替换为新主机
@@ -225,9 +240,10 @@ class ResourceUploadService:
             'pseudo_dir': self.pseudo_dir,  # 当代码移植后，引用伪目录发生变化，可以通过伪目录替换为新伪目录
             'save_dir': self.save_dir,  # TODO 建议不放快照，因为大部分情况下，并不希望用户看到文件存放的真实路径
             'save_absolute_dir': self.__save_absolute_dir,  # TODO 建议不放快照，真实绝对路径
+            'save_absolute_file_path': self.__save_absolute_file_path,  # TODO 建议不放快照，真实绝对路径
         }
         self.__file_info['counter'] = 1
-        print("> init_file: __file_info:", self.__file_info)
+        # print("> init_file: __file_info:", self.__file_info)
         return self.__file_info, None
 
     def get_md5(self):
@@ -255,7 +271,7 @@ class ResourceUploadService:
     def write_disk(self):
         try:
             # 文件写入磁盘
-            print("> write_disk: save_absolute_path:", self.__save_absolute_file_path)
+            # print("> write_disk: save_absolute_path:", self.__save_absolute_file_path)
             with open(self.__save_absolute_file_path, 'wb') as f:
                 f.write(self.__file_stream)
         except Exception as e:
